/*
 *  Program     :  SCTP CLIENT ONE TO ONE
 *  Author      :  Andres Medina 
 *  Last review :  04/04/2012 
 *  Summary     :
 *
 */
 
#include <stdio.h>
#include <stdlib.h>
#include <sys/socket.h>
#include <arpa/inet.h>
#include <netinet/sctp.h>
#include <string.h>

#define PORT 12345
#define MSG_SIZE 1000
#define NUMBER_OF_MESSAGES 1000 

/*
 *           FUNCION MAIN
 */
int main(int argc, char * argv[]){

    int sd, ret, i;
    struct sockaddr_in addr;
    char buffer[MSG_SIZE];
    socklen_t from_len;

    memset(&buffer, '1', MSG_SIZE);

    /*  Chequeo de sintaxis y errores en los argumentos ingresados */
    if ( argc != 2 || (inet_addr(argv[1]) == -1) ){
        printf("Usage: client [IP ADDRESS in form xxx.xxx.xxx.xxx]\n");
        exit(-1);
    } 

    /* Se setean los valores de familia, puerto y direccion IP del socket */
    if ( inet_aton(argv[1], &addr.sin_addr) == 0 ){
        printf("Error: invalid IP address\n");
        exit(-1);
    }
    addr.sin_port = htons(PORT);
    addr.sin_family = AF_INET; 

    /* Se crea el socket */
    if ( (sd = socket(AF_INET, SOCK_STREAM, IPPROTO_SCTP )) < 0 ){
        printf("Error: cannot create socket\n");
        exit(-1);
    }

    from_len = sizeof(addr);

    /* Nos conectamos al servidor */
    if ( (connect(sd, (struct sockaddr*) &addr, from_len)) < 0 ){
        printf("Error: cannot connect to server\n");
        exit(-1);
    }


    /* Se envia un chunk al servidor cada 1 segundo hasta completar N chunks */
    for( i = 0; i < NUMBER_OF_MESSAGES; i++ ){
    
        printf("Sending data chunk #%d ...", (i+1));

        if( (ret = send(sd, buffer, MSG_SIZE, 0)) == -1){
            printf("Error: no se puede enviar el chunk al servidor\n");
            exit(-1);
        }

        printf("Sent %d bytes to peer\n",ret);

        sleep(1);
    }

    /* Cerramos el socket en caso de terminar el programa */
    if( close(sd) < 0 ){
        printf("Error: cannot close the socket file descriptor\n");
        exit(-1);
    }

    return 0;
}
